==> component_builder-2.2.2.tar.gz: component_builder/src/Plugin/ComponentBuilder/HighlightContent.php <==
<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\Annotation\ComponentBuilder;
use Drupal\component_builder\Entity\ComponentWrapper;
use Drupal\component_builder\Entity\ComponentItem;
use Drupal\component_builder\ComponentBuilderBase;
use Drupal\Core\Render\Element;

/**
 * Provides 'Highlight Content' component.
 *
 * @ComponentBuilder(
 *   id = "highlight_content",
 *   label = @Translation("Highlight Content"),
 *   group = @Translation("General components"),
 *   template = "highlight_content",
 *   alter_wrapper = TRUE
 * )
 */
class HighlightContent extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath() {
    return $this->getComponentPath() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables) {
    if (isset($variables['elements']['#component_wrapper'])) {
      foreach (Element::children($variables['content']['field_highlight_content']) as $key) {
        $variables['articles'][] = $variables['content']['field_highlight_content'][$key]['#component_item'];
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries() {
    return [
      'css' => [
        'theme' => [
          'components/component_highlight_content/assets/style.css' => [],
        ],
      ],
      'js' => [
        'components/component_highlight_content/assets/style.js' => [],
      ],
      'dependencies' => [
        'core/drupal',
        'core/jquery',
        'core/jquery.once',
      ],
      "version" => "VERSION",
    ];
  }

}

==> component_builder-3.0.2.tar.gz: component_builder/src/Plugin/ComponentBuilder/HighlightContent.php <==
<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\ComponentBuilderBase;
use Drupal\Core\Render\Element;

/**
 * Provides 'Highlight Content' component.
 *
 * @ComponentBuilder(
 *   id = "highlight_content",
 *   label = @Translation("Highlight Content"),
 *   group = @Translation("Content style (paragraph style)"),
 *   category = @Translation("Content style (paragraph style)"),
 *   template = "highlight_content",
 *   alter_wrapper = TRUE
 * )
 */
class HighlightContent extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath() {
    return $this->getComponentPath() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables) {
    if (isset($variables['elements']['#component_wrapper'])) {
      foreach (Element::children($variables['content']['field_highlight_content']) as $key) {
        $variables['articles'][] = $variables['content']['field_highlight_content'][$key]['#component_item'];
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries() {
    return [
      'css' => [
        'theme' => [
          'components/component_highlight_content/assets/style.css' => [],
        ],
      ],
      'js' => [
        'components/component_highlight_content/assets/style.js' => [],
      ],
      'dependencies' => [
        'core/drupal',
        'core/jquery',
        'core/jquery.once',
      ],
      "version" => "VERSION",
    ];
  }

}
